==> finterstellar-0.2.11-py3-none-any.whl: finterstellar/data_prep.py <==

from . import util
import pandas as pd
import numpy as np
import requests, json


def get_price(symbol, start_date=None, end_date=None, decimal_duex=True):
    '''
    :param symbol: Symbol or ticker of equity by finance.yahoo.com
    :param start_date: The first date of period
    :param end_date: The last date of period
    :param decimal_duex: Set false not to round up
    :return: Historical close prices
    '''
    # symbol = util.str_to_list(symbol)
    end_date = pd.to_datetime(end_date).date() if end_date else pd.Timestamp.today().date()
    start_date = pd.to_datetime(start_date).date() if start_date else util.months_before(end_date, 12)
    df = _get_daily_price(symbol, start=start_date, end=end_date)['Close']
    __decimal_formatter(decimal_duex)
    return df[symbol]


def get_ohlc(symbol, start_date=None, end_date=None, decimal_duex=True):
    '''
    :param symbol: Symbol or ticker of equity by finance.yahoo.com
    :param start_date: The first date of period
    :param end_date: The last date of period
    :param decimal_duex: Set false not to round up
    :return: historical open, high, low, close prices and trade volume
    '''
    end_date = pd.to_datetime(end_date).date() if end_date else pd.Timestamp.today().date()
    start_date = pd.to_datetime(start_date).date() if start_date else util.months_before(end_date, 12)
    df = _get_daily_price(symbol, start=start_date, end=end_date)
    __decimal_formatter(decimal_duex)
    return df


def _get_multiple_prices(symbols, dates):
    prices = pd.DataFrame()
    for s in symbols:
        tmp = _get_daily_price(s, start=dates[0], end=dates[-1])['Close']
        tmp.rename(s, inplace=True)
        prices = pd.concat([prices, tmp], axis=1)
        prices.index = pd.to_datetime(prices.index)
    return prices.loc[dates]


def __get_month_ends(start_date=None, end_date=None):
    checker = _get_daily_price('SPY', start=start_date, end=end_date)['Close']
    month_ends = checker[checker.groupby([checker.index.year, checker.index.month]).apply(lambda s: np.max(s.index))].index
    return month_ends


def __get_month_end_prices(symbols, start_date=None, end_date=None):
    checker = _get_daily_price('SPY', start=start_date, end=end_date)['Close']
    month_ends = checker[checker.groupby([checker.index.year, checker.index.month]).apply(lambda s: np.max(s.index))].index
    prices = pd.DataFrame()
    for s in symbols:
        tmp = _get_daily_price(s, start=month_ends.min(), end=month_ends.max())['Close']
        tmp.rename(s, inplace=True)
        prices = pd.concat([prices, tmp], axis=1)
        prices.index = pd.to_datetime(prices.index)
    return prices.loc[month_ends]


def __decimal_formatter(duex):
    if duex:
        pd.options.display.float_format = '{:,.2f}'.format
    else:
        pd.options.display.float_format = '{:,.6f}'.format


headers = {
    'User-Agent': 'Mozilla',
    'X-Requested-With': 'XMLHttpRequest',
}


def _get_daily_price(symbol, interval='1d', range=None, start=None, end=None):
    symbol = symbol.replace('.','-')
    params = {
        'region': 'US',
        'interval': interval,
        'corsDomain': 'finance.yahoo.com',
        '.tsrc': 'finance',
        'range': range if range else None,
        'period1': (pd.Timestamp(start) - pd.Timestamp("1970-01-01")) // pd.Timedelta('1s') if start else 946688460,
        'period2': (pd.Timestamp(end) + pd.Timedelta(days=1) - pd.Timestamp("1970-01-01")) // pd.Timedelta('1s') \
            if end else (pd.Timestamp.today() + pd.Timedelta(days=1) - pd.Timestamp("1970-01-01")) // pd.Timedelta('1s'),
    }
    url = 'https://query1.finance.yahoo.com/v8/finance/chart/{}'.format(symbol)
    r = requests.get(url, headers=headers, params=params)
    raw = json.loads(r.text)
    rst = _make_ohlc(raw)
    return rst


def _make_ohlc(raw):
    time_offset = raw['chart']['result'][0]['meta']['gmtoffset']
    times = pd.to_datetime([x + time_offset for x in raw['chart']['result'][0]['timestamp']], unit='s').date
    open = raw['chart']['result'][0]['indicators']['quote'][0]['open']
    high = raw['chart']['result'][0]['indicators']['quote'][0]['high']
    low = raw['chart']['result'][0]['indicators']['quote'][0]['low']
    close = raw['chart']['result'][0]['indicators']['quote'][0]['close']
    # close = raw['chart']['result'][0]['indicators']['adjclose'][0]['adjclose']
    volume = raw['chart']['result'][0]['indicators']['quote'][0]['volume']
    d = {
        'Open': open,
        'High': high,
        'Low': low,
        'Close': close,
        'Volume': volume,
    }
    data = pd.DataFrame(d, index=times)
    data = data.round(2)
    return data

==> finterstellar-0.2.12-py3-none-any.whl: finterstellar/data_prep.py <==
import pandas as pd
import numpy as np
import requests, json


def get_price(symbol, start_date=None, end_date=None, decimal_duex=True):
    '''
    :param symbol: Symbol or ticker of equity by finance.yahoo.com
    :param start_date: The first date of period
    :param end_date: The last date of period
    :param decimal_duex: Set false not to round up
    :return: Historical close prices
    '''
    symbols = str_to_list(symbol)
    end_date = pd.to_datetime(end_date).date() if end_date else pd.Timestamp.today().date()
    start_date = pd.to_datetime(start_date).date() if start_date else months_before(end_date, 12)
    df = _get_daily_price(symbols, start=start_date, end=end_date)['Close']
    df.rename(symbol, inplace=True)
    print(df)
    __decimal_formatter(decimal_duex)
    return df


def get_ohlc(symbol, start_date=None, end_date=None, decimal_duex=True):
    '''
    :param symbol: Symbol or ticker of equity by finance.yahoo.com
    :param start_date: The first date of period
    :param end_date: The last date of period
    :param decimal_duex: Set false not to round up
    :return: historical open, high, low, close prices and trade volume
    '''
    end_date = pd.to_datetime(end_date).date() if end_date else pd.Timestamp.today().date()
    start_date = pd.to_datetime(start_date).date() if start_date else months_before(end_date, 12)
    df = _get_daily_price(symbol, start=start_date, end=end_date)
    __decimal_formatter(decimal_duex)
    return df


def _get_multiple_prices(symbols, dates):
    prices = pd.DataFrame()
    for s in symbols:
        tmp = _get_daily_price(s, start=dates[0], end=dates[-1])['Close']
        tmp.rename(s, inplace=True)
        prices = pd.concat([prices, tmp], axis=1)
        prices.index = pd.to_datetime(prices.index)
    return prices.loc[dates]


def __get_month_ends(start_date=None, end_date=None):
    checker = _get_daily_price('SPY', start=start_date, end=end_date)['Close']
    month_ends = checker[checker.groupby([checker.index.year, checker.index.month]).apply(lambda s: np.max(s.index))].index
    return month_ends


def __get_month_end_prices(symbols, start_date=None, end_date=None):
    checker = _get_daily_price('SPY', start=start_date, end=end_date)['Close']
    month_ends = checker[checker.groupby([checker.index.year, checker.index.month]).apply(lambda s: np.max(s.index))].index
    prices = pd.DataFrame()
    for s in symbols:
        tmp = _get_daily_price(s, start=month_ends.min(), end=month_ends.max())['Close']
        tmp.rename(s, inplace=True)
        prices = pd.concat([prices, tmp], axis=1)
        prices.index = pd.to_datetime(prices.index)
    return prices.loc[month_ends]


def __decimal_formatter(duex):
    if duex:
        pd.options.display.float_format = '{:,.2f}'.format
    else:
        pd.options.display.float_format = '{:,.6f}'.format


headers = {
    'User-Agent': 'Mozilla',
    'X-Requested-With': 'XMLHttpRequest',
}


def _get_daily_price(symbol, interval='1d', range=None, start=None, end=None):
    symbol = symbol[0].replace('.','-')
    params = {
        'region': 'US',
        'interval': interval,
        'corsDomain': 'finance.yahoo.com',
        '.tsrc': 'finance',
        'range': range if range else None,
        'period1': (pd.Timestamp(start) - pd.Timestamp("1970-01-01")) // pd.Timedelta('1s') if start else 946688460,
        'period2': (pd.Timestamp(end) + pd.Timedelta(days=1) - pd.Timestamp("1970-01-01")) // pd.Timedelta('1s') \
            if end else (pd.Timestamp.today() + pd.Timedelta(days=1) - pd.Timestamp("1970-01-01")) // pd.Timedelta('1s'),
    }
    url = 'https://query1.finance.yahoo.com/v8/finance/chart/{}'.format(symbol)
    r = requests.get(url, headers=headers, params=params)
    raw = json.loads(r.text)
    rst = _make_ohlc(raw)
    return rst


def _make_ohlc(raw):
    time_offset = raw['chart']['result'][0]['meta']['gmtoffset']
    times = pd.to_datetime([x + time_offset for x in raw['chart']['result'][0]['timestamp']], unit='s').date
    open = raw['chart']['result'][0]['indicators']['quote'][0]['open']
    high = raw['chart']['result'][0]['indicators']['quote'][0]['high']
    low = raw['chart']['result'][0]['indicators']['quote'][0]['low']
    close = raw['chart']['result'][0]['indicators']['quote'][0]['close']
    # close = raw['chart']['result'][0]['indicators']['adjclose'][0]['adjclose']
    volume = raw['chart']['result'][0]['indicators']['quote'][0]['volume']
    d = {
        'Open': open,
        'High': high,
        'Low': low,
        'Close': close,
        'Volume': volume,
    }
    data = pd.DataFrame(d, index=times)
    data = data.round(2)
    return data


def str_to_list(s):
    '''
    Convert string to list
    :param s: String or List
    :return: List
    '''
    if type(s) == list:
        cds = s
    else:
        cds = []
        cds.append(s)
    return cds


def months_before(date, n):
    '''
    Get date n months before given date
    :param date: Base date
    :param n: N months
    :return: Date
    '''
    d = pd.to_datetime(date) - pd.DateOffset(months=n)
    if d.weekday() > 4:
        adj = d.weekday() - 4
        d += pd.DateOffset(days=adj)
    else:
        d = d
    return d.date()


if __name__ == '__main__':
    get_price('AAPL')
